@@ -50,4 +50,7 @@ async def cli():
 
 
 def cli_sync():
-    asyncio.run(cli())
+    try:
+        asyncio.run(cli())
+    except KeyboardInterrupt:
+        pass
